# rescue-api

This is a Python 3 implementation of the RescueTime API.

## Resources

You can find this project [on PyPi][pypi].

You should also familiarize yourself with the official [RescueTime API docs][official].

[official]: https://www.rescuetime.com/anapi/setup/documentation
[pypi]: https://pypi.org/project/rescue-api/
